Package: scGraphVerse
Title: scGraphVerse: A Gene Network Analysis Package
Version: 1.0.0
Authors@R: c(
    person("Francesco", "Cecere", 
           email = "francesco.cecerengs@gmail.com", 
           role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-0329-0870")),
    person("Annamaria", "Carissimo", 
           role = "aut"),
    person("Daniela", "De Canditiis", 
           role = "aut"),
    person("Claudia", "Angelini", 
           role = c("aut", "fnd")))
Description: A package for inferring, comparing, and visualizing gene networks 
    from single-cell RNA sequencing data. It integrates multiple methods (GENIE3, 
    GRNBoost2, ZILGM, PCzinb, and JRF) for robust network inference, supports consensus 
    building across methods or datasets, and provides tools for evaluating regulatory 
    structure and community similarity. GRNBoost2 requires Python package 'arboreto' 
    which can be installed using init_py(install_missing = TRUE). This package 
    includes adapted functions from ZILGM (Park et al., 2021), JRF (Petralia et al., 2015), 
    and learn2count (Nguyen et al. 2023) packages with proper attribution under GPL-2 license.
License: GPL-3 + file LICENSE
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.3
biocViews: GeneRegulation, NetworkInference, SingleCell, RNASeq,
        Visualization, Software, GraphAndNetwork, GeneSetEnrichment,
        NetworkEnrichment, Pathways, Sequencing, Reactome, Network,
        KEGG
URL: https://ngsFC.github.io/scGraphVerse
BugReports: https://github.com/ngsFC/scGraphVerse/issues
Depends: R (>= 4.5.0)
Imports: BiocBaseUtils, BiocParallel (>= 1.30.0), doParallel, doRNG,
        GENIE3, Matrix, MultiAssayExperiment, SingleCellExperiment,
        SummarizedExperiment, distributions3, dplyr, grDevices,
        graphics, httr, igraph, jsonlite, methods, parallel,
        reticulate, tidyr, glmnet, MASS, utils, stats, S4Vectors,
        graph, mpath
Suggests: AnnotationDbi, BiocStyle, clusterProfiler, DOSE, enrichplot,
        fmsb, ggplot2, ggraph, gridExtra, INetTool, org.Hs.eg.db,
        org.Mm.eg.db, patchwork, pROC, RColorBrewer, ReactomePA,
        rentrez, robin, scales, Seurat, STRINGdb, testthat (>= 3.0.0),
        knitr, rmarkdown, tidyverse, magick, celldex, SingleR,
        TENxPBMCData, scater, GenomeInfoDb, GenomicRanges,
VignetteBuilder: knitr
LazyData: false
SystemRequirements: Python (>= 3.6) and arboreto Python package for
        GRNBoost2 method. Use init_py(install_missing = TRUE) for
        automated installation.
git_url: https://git.bioconductor.org/packages/scGraphVerse
git_branch: RELEASE_3_22
git_last_commit: 425f2dc
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: yes
Packaged: 2025-10-30 06:24:19 UTC; biocbuild
Author: Francesco Cecere [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-0329-0870>),
  Annamaria Carissimo [aut],
  Daniela De Canditiis [aut],
  Claudia Angelini [aut, fnd]
Maintainer: Francesco Cecere <francesco.cecerengs@gmail.com>
