# Generated by roxygen2: do not edit by hand
useDynLib(scGraphVerse, .registration = TRUE)

export(PCzinb)
export(build_network_se)
export(classify_edges)
export(community_path)
export(community_similarity)
export(compare_consensus)
export(compute_community_metrics)
export(compute_topology_metrics)
export(create_consensus)
export(create_mae)
export(cutoff_adjacency)
export(download_Atlas)
export(earlyj)
export(edge_mining)
export(generate_adjacency)
export(infer_networks)
export(init_py)
export(plotROC)
export(plot_community_comparison)
export(plot_network_comparison)
export(plotg)
export(pscores)
export(selgene)
export(stringdb_adjacency)
export(symmetrize)
export(zinb_simdata)
import(BiocParallel)
import(methods)
importClassesFrom(Matrix,dgCMatrix)
importClassesFrom(graph,graphNEL)
importFrom(BiocParallel,MulticoreParam)
importFrom(BiocParallel,SerialParam)
importFrom(BiocParallel,bplapply)
importFrom(BiocParallel,bpparam)
importFrom(BiocParallel,bpworkers)
importFrom(MASS,glm.nb)
importFrom(MASS,negative.binomial)
importFrom(Matrix,Matrix)
importFrom(MultiAssayExperiment,MultiAssayExperiment)
importFrom(S4Vectors,DataFrame)
importFrom(S4Vectors,`metadata<-`)
importFrom(S4Vectors,metadata)
importFrom(SingleCellExperiment,SingleCellExperiment)
importFrom(SingleCellExperiment,`rowPair<-`)
importFrom(SummarizedExperiment,SummarizedExperiment)
importFrom(SummarizedExperiment,assay)
importFrom(SummarizedExperiment,assayNames)
importFrom(SummarizedExperiment,assays)
importFrom(distributions3,rzinbinom)
importFrom(doParallel,registerDoParallel)
importFrom(doRNG,"%dorng%")
importFrom(dplyr,arrange)
importFrom(dplyr,bind_rows)
importFrom(dplyr,select)
importFrom(glmnet,glmnet)
importFrom(grDevices,colorRampPalette)
importFrom(graphics,barplot)
importFrom(graphics,legend)
importFrom(graphics,par)
importFrom(httr,GET)
importFrom(httr,POST)
importFrom(httr,content)
importFrom(httr,status_code)
importFrom(igraph,V)
importFrom(igraph,as_adjacency_matrix)
importFrom(igraph,as_edgelist)
importFrom(igraph,compare)
importFrom(igraph,degree)
importFrom(igraph,delete_vertices)
importFrom(igraph,ecount)
importFrom(igraph,edge_density)
importFrom(igraph,graph_from_adjacency_matrix)
importFrom(igraph,induced_subgraph)
importFrom(igraph,is_igraph)
importFrom(igraph,modularity)
importFrom(igraph,transitivity)
importFrom(igraph,vcount)
importFrom(jsonlite,fromJSON)
importFrom(methods,is)
importFrom(methods,slotNames)
importFrom(mpath,glmreg)
importFrom(parallel,makeCluster)
importFrom(parallel,stopCluster)
importFrom(reticulate,conda_install)
importFrom(reticulate,import)
importFrom(reticulate,py_install)
importFrom(reticulate,py_module_available)
importFrom(reticulate,use_python)
importFrom(stats,AIC)
importFrom(stats,BIC)
importFrom(stats,as.formula)
importFrom(stats,coefficients)
importFrom(stats,dnbinom)
importFrom(stats,glm)
importFrom(stats,glm.fit)
importFrom(stats,na.omit)
importFrom(stats,optim)
importFrom(stats,optimize)
importFrom(stats,pchisq)
importFrom(stats,pnorm)
importFrom(stats,quantile)
importFrom(stats,rbinom)
importFrom(stats,rnbinom)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,var)
importFrom(tidyr,all_of)
importFrom(utils,combn)
importFrom(utils,head)
importFrom(utils,modifyList)
