#' Toy adjacency matrix for examples
#'
#' An adjacency matrix generated using real dataset and STRINGdb for
#' demonstrating functions in the scGraphVerse package.
#'
#' @format A matrix of dimension 10x10.
#' @usage data(toy_adj_matrix)
#' @examples
#' data(toy_adj_matrix)
#' str(toy_adj_matrix)
"toy_adj_matrix"
